# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr
from marketplace_server_connector.models.import_buyer_in import ImportBuyerIn
from marketplace_server_connector.models.payment_type import PaymentType
from marketplace_server_connector.models.provider import Provider

class ImportOrderIn(BaseModel):
    """
    ImportOrderIn
    """
    provider: Provider = Field(...)
    buyer: ImportBuyerIn = Field(...)
    external_product_id: StrictStr = Field(...)
    product_title: Optional[StrictStr] = None
    payment_type: Optional[PaymentType] = None
    occurred_at: StrictInt = Field(...)
    external_order_id: Optional[StrictStr] = None
    external_subscription_id: Optional[StrictStr] = None
    period_end: Optional[StrictInt] = None
    amount: Optional[StrictInt] = None
    is_test: Optional[StrictBool] = False
    __properties = ["provider", "buyer", "external_product_id", "product_title", "payment_type", "occurred_at", "external_order_id", "external_subscription_id", "period_end", "amount", "is_test"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ImportOrderIn:
        """Create an instance of ImportOrderIn from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of buyer
        if self.buyer:
            _dict['buyer'] = self.buyer.to_dict()
        # set to None if product_title (nullable) is None
        # and __fields_set__ contains the field
        if self.product_title is None and "product_title" in self.__fields_set__:
            _dict['product_title'] = None

        # set to None if external_order_id (nullable) is None
        # and __fields_set__ contains the field
        if self.external_order_id is None and "external_order_id" in self.__fields_set__:
            _dict['external_order_id'] = None

        # set to None if external_subscription_id (nullable) is None
        # and __fields_set__ contains the field
        if self.external_subscription_id is None and "external_subscription_id" in self.__fields_set__:
            _dict['external_subscription_id'] = None

        # set to None if period_end (nullable) is None
        # and __fields_set__ contains the field
        if self.period_end is None and "period_end" in self.__fields_set__:
            _dict['period_end'] = None

        # set to None if amount (nullable) is None
        # and __fields_set__ contains the field
        if self.amount is None and "amount" in self.__fields_set__:
            _dict['amount'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ImportOrderIn:
        """Create an instance of ImportOrderIn from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ImportOrderIn.parse_obj(obj)

        _obj = ImportOrderIn.parse_obj({
            "provider": obj.get("provider"),
            "buyer": ImportBuyerIn.from_dict(obj.get("buyer")) if obj.get("buyer") is not None else None,
            "external_product_id": obj.get("external_product_id"),
            "product_title": obj.get("product_title"),
            "payment_type": obj.get("payment_type"),
            "occurred_at": obj.get("occurred_at"),
            "external_order_id": obj.get("external_order_id"),
            "external_subscription_id": obj.get("external_subscription_id"),
            "period_end": obj.get("period_end"),
            "amount": obj.get("amount"),
            "is_test": obj.get("is_test") if obj.get("is_test") is not None else False
        })
        return _obj





# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from marketplace_server_connector.api.integrations_api import IntegrationsApi  # noqa: E501


class TestIntegrationsApi(unittest.IsolatedAsyncioTestCase):
    """IntegrationsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = IntegrationsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_v1_integrations_post(self) -> None:
        """Test case for create_v1_integrations_post

        Connect a provider integration  # noqa: E501
        """
        pass

    async def test_delete_integration_v1_integrations_integration_id_delete(self) -> None:
        """Test case for delete_integration_v1_integrations_integration_id_delete

        Disconnect (delete) an integration  # noqa: E501
        """
        pass

    async def test_get_integration_v1_integrations_integration_id_get(self) -> None:
        """Test case for get_integration_v1_integrations_integration_id_get

        Get one integration  # noqa: E501
        """
        pass

    async def test_list_integrations_v1_integrations_get(self) -> None:
        """Test case for list_integrations_v1_integrations_get

        List the portal's provider integrations  # noqa: E501
        """
        pass

    async def test_setup_webhooks_v1_integrations_integration_id_webhooks_setup_post(self) -> None:
        """Test case for setup_webhooks_v1_integrations_integration_id_webhooks_setup_post

        (Re-)register the provider-side webhook  # noqa: E501
        """
        pass

    async def test_sync_products_v1_integrations_integration_id_products_sync_post(self) -> None:
        """Test case for sync_products_v1_integrations_integration_id_products_sync_post

        Sync products from one integration's provider  # noqa: E501
        """
        pass

    async def test_test_credentials_v1_integrations_test_post(self) -> None:
        """Test case for test_credentials_v1_integrations_test_post

        Test provider credentials (before saving)  # noqa: E501
        """
        pass

    async def test_test_integration_v1_integrations_integration_id_test_post(self) -> None:
        """Test case for test_integration_v1_integrations_integration_id_test_post

        Test an integration's saved connection  # noqa: E501
        """
        pass

    async def test_update_integration_v1_integrations_integration_id_patch(self) -> None:
        """Test case for update_integration_v1_integrations_integration_id_patch

        Update an integration (rotate credentials / enable-disable)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError
from typing import overload, Optional, Union, Awaitable

from pydantic import StrictBool, StrictInt

from typing import Optional

from marketplace_server_connector.models.integration_in import IntegrationIn
from marketplace_server_connector.models.integration_patch_in import IntegrationPatchIn
from marketplace_server_connector.models.integration_test_in import IntegrationTestIn
from marketplace_server_connector.models.wrapped_response_id_out import WrappedResponseIdOut
from marketplace_server_connector.models.wrapped_response_integration_out import WrappedResponseIntegrationOut
from marketplace_server_connector.models.wrapped_response_integration_sync_out import WrappedResponseIntegrationSyncOut
from marketplace_server_connector.models.wrapped_response_integration_test_out import WrappedResponseIntegrationTestOut
from marketplace_server_connector.models.wrapped_response_list_integration_out import WrappedResponseListIntegrationOut
from marketplace_server_connector.models.wrapped_response_webhook_setup_out import WrappedResponseWebhookSetupOut

from marketplace_server_connector.api_client import ApiClient
from marketplace_server_connector.api_response import ApiResponse
from marketplace_server_connector.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class IntegrationsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    async def create_v1_integrations_post(self, integration_in : IntegrationIn, **kwargs) -> WrappedResponseIdOut:  # noqa: E501
        """Connect a provider integration  # noqa: E501

        For providers with a registration API (stripe, digistore, elopage, upgates) this also registers our webhook/IPN endpoint with the provider and stores the resulting verify secret; registration failure fails the connect with 400. Other providers: paste the webhook URL into the provider dashboard manually.  # noqa: E501

        :param integration_in: (required)
        :type integration_in: IntegrationIn
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: WrappedResponseIdOut
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the create_v1_integrations_post_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.create_v1_integrations_post_with_http_info(integration_in, **kwargs)  # noqa: E501

    @validate_arguments
    async def create_v1_integrations_post_with_http_info(self, integration_in : IntegrationIn, **kwargs) -> ApiResponse:  # noqa: E501
        """Connect a provider integration  # noqa: E501

        For providers with a registration API (stripe, digistore, elopage, upgates) this also registers our webhook/IPN endpoint with the provider and stores the resulting verify secret; registration failure fails the connect with 400. Other providers: paste the webhook URL into the provider dashboard manually.  # noqa: E501

        :param integration_in: (required)
        :type integration_in: IntegrationIn
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(WrappedResponseIdOut, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'integration_in'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_v1_integrations_post" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['integration_in'] is not None:
            _body_params = _params['integration_in']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Bearer Authorization', 'ServerName Authorization']  # noqa: E501

        _response_types_map = {
            '200': "WrappedResponseIdOut",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/v1/integrations', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def delete_integration_v1_integrations_integration_id_delete(self, integration_id : StrictInt, **kwargs) -> WrappedResponseIdOut:  # noqa: E501
        """Disconnect (delete) an integration  # noqa: E501

        409 if the integration still has products (they back access-package links) — disable it (is_active=false) or remove its products first.  # noqa: E501

        :param integration_id: (required)
        :type integration_id: int
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: WrappedResponseIdOut
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the delete_integration_v1_integrations_integration_id_delete_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.delete_integration_v1_integrations_integration_id_delete_with_http_info(integration_id, **kwargs)  # noqa: E501

    @validate_arguments
    async def delete_integration_v1_integrations_integration_id_delete_with_http_info(self, integration_id : StrictInt, **kwargs) -> ApiResponse:  # noqa: E501
        """Disconnect (delete) an integration  # noqa: E501

        409 if the integration still has products (they back access-package links) — disable it (is_active=false) or remove its products first.  # noqa: E501

        :param integration_id: (required)
        :type integration_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(WrappedResponseIdOut, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'integration_id'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_integration_v1_integrations_integration_id_delete" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['integration_id'] is not None:
            _path_params['integration_id'] = _params['integration_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['Bearer Authorization', 'ServerName Authorization']  # noqa: E501

        _response_types_map = {
            '200': "WrappedResponseIdOut",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/v1/integrations/{integration_id}', 'DELETE',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def get_integration_v1_integrations_integration_id_get(self, integration_id : StrictInt, **kwargs) -> WrappedResponseIntegrationOut:  # noqa: E501
        """Get one integration  # noqa: E501


        :param integration_id: (required)
        :type integration_id: int
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: WrappedResponseIntegrationOut
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_integration_v1_integrations_integration_id_get_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.get_integration_v1_integrations_integration_id_get_with_http_info(integration_id, **kwargs)  # noqa: E501

    @validate_arguments
    async def get_integration_v1_integrations_integration_id_get_with_http_info(self, integration_id : StrictInt, **kwargs) -> ApiResponse:  # noqa: E501
        """Get one integration  # noqa: E501


        :param integration_id: (required)
        :type integration_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(WrappedResponseIntegrationOut, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'integration_id'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_integration_v1_integrations_integration_id_get" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['integration_id'] is not None:
            _path_params['integration_id'] = _params['integration_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['Bearer Authorization', 'ServerName Authorization']  # noqa: E501

        _response_types_map = {
            '200': "WrappedResponseIntegrationOut",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/v1/integrations/{integration_id}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def list_integrations_v1_integrations_get(self, active_only : Optional[StrictBool] = None, **kwargs) -> WrappedResponseListIntegrationOut:  # noqa: E501
        """List the portal's provider integrations  # noqa: E501

        Query: active_only? (default false — includes disabled). Credentials are never returned; only the credential key names that are set.  # noqa: E501

        :param active_only:
        :type active_only: bool
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: WrappedResponseListIntegrationOut
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the list_integrations_v1_integrations_get_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.list_integrations_v1_integrations_get_with_http_info(active_only, **kwargs)  # noqa: E501

    @validate_arguments
    async def list_integrations_v1_integrations_get_with_http_info(self, active_only : Optional[StrictBool] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """List the portal's provider integrations  # noqa: E501

        Query: active_only? (default false — includes disabled). Credentials are never returned; only the credential key names that are set.  # noqa: E501

        :param active_only:
        :type active_only: bool
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(WrappedResponseListIntegrationOut, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'active_only'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_integrations_v1_integrations_get" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('active_only') is not None:  # noqa: E501
            _query_params.append(('active_only', _params['active_only']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['Bearer Authorization', 'ServerName Authorization']  # noqa: E501

        _response_types_map = {
            '200': "WrappedResponseListIntegrationOut",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/v1/integrations', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def setup_webhooks_v1_integrations_integration_id_webhooks_setup_post(self, integration_id : StrictInt, **kwargs) -> WrappedResponseWebhookSetupOut:  # noqa: E501
        """(Re-)register the provider-side webhook  # noqa: E501

        Points the provider's webhook/IPN at our endpoint using the STORED credentials (registration also runs automatically on connect and credential rotation). Use to re-sync after a provider-side deletion. supported=false => manual dashboard setup for this provider.  # noqa: E501

        :param integration_id: (required)
        :type integration_id: int
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: WrappedResponseWebhookSetupOut
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the setup_webhooks_v1_integrations_integration_id_webhooks_setup_post_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.setup_webhooks_v1_integrations_integration_id_webhooks_setup_post_with_http_info(integration_id, **kwargs)  # noqa: E501

    @validate_arguments
    async def setup_webhooks_v1_integrations_integration_id_webhooks_setup_post_with_http_info(self, integration_id : StrictInt, **kwargs) -> ApiResponse:  # noqa: E501
        """(Re-)register the provider-side webhook  # noqa: E501

        Points the provider's webhook/IPN at our endpoint using the STORED credentials (registration also runs automatically on connect and credential rotation). Use to re-sync after a provider-side deletion. supported=false => manual dashboard setup for this provider.  # noqa: E501

        :param integration_id: (required)
        :type integration_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(WrappedResponseWebhookSetupOut, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'integration_id'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method setup_webhooks_v1_integrations_integration_id_webhooks_setup_post" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['integration_id'] is not None:
            _path_params['integration_id'] = _params['integration_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['Bearer Authorization', 'ServerName Authorization']  # noqa: E501

        _response_types_map = {
            '200': "WrappedResponseWebhookSetupOut",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/v1/integrations/{integration_id}/webhooks/setup', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def sync_products_v1_integrations_integration_id_products_sync_post(self, integration_id : StrictInt, **kwargs) -> WrappedResponseIntegrationSyncOut:  # noqa: E501
        """Sync products from one integration's provider  # noqa: E501


        :param integration_id: (required)
        :type integration_id: int
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: WrappedResponseIntegrationSyncOut
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the sync_products_v1_integrations_integration_id_products_sync_post_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.sync_products_v1_integrations_integration_id_products_sync_post_with_http_info(integration_id, **kwargs)  # noqa: E501

    @validate_arguments
    async def sync_products_v1_integrations_integration_id_products_sync_post_with_http_info(self, integration_id : StrictInt, **kwargs) -> ApiResponse:  # noqa: E501
        """Sync products from one integration's provider  # noqa: E501


        :param integration_id: (required)
        :type integration_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(WrappedResponseIntegrationSyncOut, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'integration_id'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method sync_products_v1_integrations_integration_id_products_sync_post" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['integration_id'] is not None:
            _path_params['integration_id'] = _params['integration_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['Bearer Authorization', 'ServerName Authorization']  # noqa: E501

        _response_types_map = {
            '200': "WrappedResponseIntegrationSyncOut",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/v1/integrations/{integration_id}/products/sync', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def test_credentials_v1_integrations_test_post(self, integration_test_in : IntegrationTestIn, **kwargs) -> WrappedResponseIntegrationTestOut:  # noqa: E501
        """Test provider credentials (before saving)  # noqa: E501

        Body: {provider, credentials}. Validates the credentials against the provider's API without saving anything — for the connect/edit forms. Providers without a testable API return supported=false. To re-check an already-saved connection use POST /{id}/test.  # noqa: E501

        :param integration_test_in: (required)
        :type integration_test_in: IntegrationTestIn
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: WrappedResponseIntegrationTestOut
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the test_credentials_v1_integrations_test_post_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.test_credentials_v1_integrations_test_post_with_http_info(integration_test_in, **kwargs)  # noqa: E501

    @validate_arguments
    async def test_credentials_v1_integrations_test_post_with_http_info(self, integration_test_in : IntegrationTestIn, **kwargs) -> ApiResponse:  # noqa: E501
        """Test provider credentials (before saving)  # noqa: E501

        Body: {provider, credentials}. Validates the credentials against the provider's API without saving anything — for the connect/edit forms. Providers without a testable API return supported=false. To re-check an already-saved connection use POST /{id}/test.  # noqa: E501

        :param integration_test_in: (required)
        :type integration_test_in: IntegrationTestIn
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(WrappedResponseIntegrationTestOut, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'integration_test_in'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method test_credentials_v1_integrations_test_post" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['integration_test_in'] is not None:
            _body_params = _params['integration_test_in']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Bearer Authorization', 'ServerName Authorization']  # noqa: E501

        _response_types_map = {
            '200': "WrappedResponseIntegrationTestOut",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/v1/integrations/test', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def test_integration_v1_integrations_integration_id_test_post(self, integration_id : StrictInt, **kwargs) -> WrappedResponseIntegrationTestOut:  # noqa: E501
        """Test an integration's saved connection  # noqa: E501

        No body. Re-checks the STORED credentials against the provider — credentials are write-only, so this is the only way to test an existing connection.  # noqa: E501

        :param integration_id: (required)
        :type integration_id: int
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: WrappedResponseIntegrationTestOut
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the test_integration_v1_integrations_integration_id_test_post_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.test_integration_v1_integrations_integration_id_test_post_with_http_info(integration_id, **kwargs)  # noqa: E501

    @validate_arguments
    async def test_integration_v1_integrations_integration_id_test_post_with_http_info(self, integration_id : StrictInt, **kwargs) -> ApiResponse:  # noqa: E501
        """Test an integration's saved connection  # noqa: E501

        No body. Re-checks the STORED credentials against the provider — credentials are write-only, so this is the only way to test an existing connection.  # noqa: E501

        :param integration_id: (required)
        :type integration_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(WrappedResponseIntegrationTestOut, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'integration_id'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method test_integration_v1_integrations_integration_id_test_post" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['integration_id'] is not None:
            _path_params['integration_id'] = _params['integration_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['Bearer Authorization', 'ServerName Authorization']  # noqa: E501

        _response_types_map = {
            '200': "WrappedResponseIntegrationTestOut",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/v1/integrations/{integration_id}/test', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def update_integration_v1_integrations_integration_id_patch(self, integration_id : StrictInt, integration_patch_in : IntegrationPatchIn, **kwargs) -> WrappedResponseIdOut:  # noqa: E501
        """Update an integration (rotate credentials / enable-disable)  # noqa: E501

        Body: {credentials?, is_active?, sync_enabled?}. credentials replaces the whole set and re-registers the provider webhook (rotating its verify secret) for auto-registered providers; is_active=false is the safe 'disconnect' (stops webhooks granting, keeps products); sync_enabled=false excludes it from sync-all (manual product curation).  # noqa: E501

        :param integration_id: (required)
        :type integration_id: int
        :param integration_patch_in: (required)
        :type integration_patch_in: IntegrationPatchIn
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: WrappedResponseIdOut
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the update_integration_v1_integrations_integration_id_patch_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.update_integration_v1_integrations_integration_id_patch_with_http_info(integration_id, integration_patch_in, **kwargs)  # noqa: E501

    @validate_arguments
    async def update_integration_v1_integrations_integration_id_patch_with_http_info(self, integration_id : StrictInt, integration_patch_in : IntegrationPatchIn, **kwargs) -> ApiResponse:  # noqa: E501
        """Update an integration (rotate credentials / enable-disable)  # noqa: E501

        Body: {credentials?, is_active?, sync_enabled?}. credentials replaces the whole set and re-registers the provider webhook (rotating its verify secret) for auto-registered providers; is_active=false is the safe 'disconnect' (stops webhooks granting, keeps products); sync_enabled=false excludes it from sync-all (manual product curation).  # noqa: E501

        :param integration_id: (required)
        :type integration_id: int
        :param integration_patch_in: (required)
        :type integration_patch_in: IntegrationPatchIn
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(WrappedResponseIdOut, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'integration_id',
            'integration_patch_in'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_integration_v1_integrations_integration_id_patch" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['integration_id'] is not None:
            _path_params['integration_id'] = _params['integration_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['integration_patch_in'] is not None:
            _body_params = _params['integration_patch_in']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Bearer Authorization', 'ServerName Authorization']  # noqa: E501

        _response_types_map = {
            '200': "WrappedResponseIdOut",
            '422': "HTTPValidationError",
        }

        return await self.api_client.call_api(
            '/v1/integrations/{integration_id}', 'PATCH',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from marketplace_server_connector.api.products_api import ProductsApi  # noqa: E501


class TestProductsApi(unittest.IsolatedAsyncioTestCase):
    """ProductsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ProductsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_count_products_v1_products_count_get(self) -> None:
        """Test case for count_products_v1_products_count_get

        Count the portal's products  # noqa: E501
        """
        pass

    async def test_create_product_v1_products_post(self) -> None:
        """Test case for create_product_v1_products_post

        Register a product  # noqa: E501
        """
        pass

    async def test_delete_product_v1_products_product_id_delete(self) -> None:
        """Test case for delete_product_v1_products_product_id_delete

        Delete a product  # noqa: E501
        """
        pass

    async def test_import_products_v1_products_import_post(self) -> None:
        """Test case for import_products_v1_products_import_post

        Bulk-add products by hand (upsert a list)  # noqa: E501
        """
        pass

    async def test_list_products_v1_products_get(self) -> None:
        """Test case for list_products_v1_products_get

        List the portal's products (paginated)  # noqa: E501
        """
        pass

    async def test_sync_all_v1_products_sync_post(self) -> None:
        """Test case for sync_all_v1_products_sync_post

        Sync products from ALL of the portal's integrations  # noqa: E501
        """
        pass

    async def test_update_product_v1_products_product_id_patch(self) -> None:
        """Test case for update_product_v1_products_product_id_patch

        Edit a product (title / external id / archive-restore)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
